getHRUsed: getHRUsed

Description Usage Arguments

View source: R/analysis_and_visualization.R

Description

Extracts the habitat classification of habitat matrix cells contained within the boundaries of a supplied polygon (intended to be the isopleth of a KDE-based home range)

Usage

1
getHRUsed(poly, hab.mat, matsize)

Arguments

poly

A polygon of the format 'SpatialPolygons' or 'SpatialPolygonsDataFrame'. Typically the output of the 'getverticesHR' function in the 'adehabitatHR' package.

hab.mat

The habitat classification matrix (first element of the list generated by 'simlandscapes')

matsize

The size of one side of the square matrix on which the simualtion is run.


syanco/checkyourself documentation built on Jan. 18, 2021, 4:50 a.m.