getPropUsed: getPropUsed

Description Usage Arguments

View source: R/analysis_and_visualization.R

Description

Function to get the proportion of used locations (from movement model) within the habitat matching the value of 'A.coef'

Usage

1
getPropUsed(movelist, hab.mat, A.coef, matsize)

Arguments

movelist

The list of locations visitied by agent in a single model iteration.

hab.mat

The habitat matrix on which the simulation was run, needs version with 1's and 'A.coef' (not probabilities of cell IDs)

A.coef

'A.coef' used to simulate habitat - used as key to 'hab.mat'

matsize

The size of one side of the square matrix on which the simualtion is run


syanco/checkyourself documentation built on Jan. 18, 2021, 4:50 a.m.