getcombos: getcombos

Description Usage Arguments Value

View source: R/analysis_and_visualization.R

Description

Creates 2 lists which, paired, provide each unidirectional pairwise combination (outer product) of the two lists. Meant as a component function to assist in creating heatmaps.

Usage

1
getcombos(X, Y)

Arguments

X

The first list of model objects. It is suggested that each list element be named.

Y

The second list.

Value

A two element list which contains the paired combinations of the supplied model lists


syanco/checkyourself documentation built on Jan. 18, 2021, 4:50 a.m.