gettissue: gettissue

Description Usage Arguments Value

View source: R/gettissueiso.R

Description

Function to calculate tissue isotope values from a single simulated consumer.

Usage

1
gettissue(foodlist, window, time)

Arguments

foodlist

The list of food items sampled by an individual consumer. This is the list generated by 'eatfoodsteps'. Note that this function is intededed to be called from 'getiso' which iterates this function across all individuals in a population of consumers (i.e., the list generated by 'eatfood').

window

Integer, the consumer isotope integration window representing the number of steps across which prey isotope values are integrated in an individual consumer to generate consumer tissue isotope values. Window must be less than or equal to 'time'.

time

Integer, the step at which the simulated consumer tissue sample is to be taken. Must be less than or equal to the total number of steps simulated.

Value

A vector containing the C and N values for the simulated consumer tissue. Tissue values represent the mean isotope values for the prey consumed between 'time' - 'window' and 'time'.


syanco/checkyourself documentation built on Jan. 18, 2021, 4:50 a.m.