probsel: probsel

Description Usage Arguments Details

View source: R/move.R

Description

Makes probabalistic selections of a cell based on the mixture of two probability matrices. Not intended to be called directly - used by 'chooseloc'

Usage

1
probsel(hab.prob, lambda, move.list, coef.d, coef.r, matsize, ...)

Arguments

hab.prob

matrix, the habitat matrix with cell values representing the habitat-only probabilities (uncorrected for the mixing proportions with distance). Typically the second element of the list returned by simlandscapes.

lambda

numeric, the strength of the declining exponental function that controls how "reluctant" the agent is to move large distances. Must be <1.

move.list

list, the current 'move.list' being maintained by 'chooseloc'. Used to find the current agent position.

coef.d

numeric, the relative weight to give the distance preference.

coef.r

numeric, the relative weight to give the habitat preference.

matsize

integer, the size in number of cells of one side of the square matrix on which the simulation is being run.

...

Details

(based on https://scrogster.wordpress.com/2012/04/22/using-r-for-spatial-sampling-with-selection-probabilities-defined-in-a-raster/)


syanco/checkyourself documentation built on Jan. 18, 2021, 4:50 a.m.