Description Usage Arguments Value
A function to simulate a single individual moving with varying mixtures of preference for habitat and/or short steps.
1 2 3 4 5 6 7 8 9 10 11 |
hab.prob |
matrix, the habitat matrix with cell values representing the habitat-only probabilities (uncorrected for the mixing proportions with distance). Typically the second element of the list returned by simlandscapes. |
pd.rate |
numeric, the probability of returning to the central place to "deliver prey" to nest/den/etc. on any given step (given the agent isnot currently located at the central place.) Must be <1. |
steps |
integer, the number of steps the agent should take |
lambda |
numeric, the strength of the declining exponental function that controls how "reluctant" the agent is to move large distances. Must be <1. |
coef.d |
numeric, can be factor or proportion representing the relative strength of the preference to move short steps compared to the strength of the preference for habitat. |
coef.r |
numeric, can be factor or proportion representing the relative strength of the preference for habitat compared to the strength of the preference for short steps. |
matsize |
integer, the size in number of cells of one side of the square matrix on which the simulation is being run. |
... |
Returns the list of positions for the simulated individual.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.