Description Usage Arguments Value
View source: R/analysis_and_visualization.R
Creates 2 lists which, paired, provide each unidirectional pairwise combination (outer product) of the two lists. Meant as a component function to assist in creating heatmaps.
1 | getcombos(X, Y)
|
X |
The first list of model objects. It is suggested that each list element be named. |
Y |
The second list. |
A two element list which contains the paired combinations of the supplied model lists
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.