Description Usage Arguments Value Examples
View source: R/analysis_and_visualization.R
The vectorized wrapper function for 'singleheatmat' that can walk through the paired list of model combiantions produced by 'getcombos' and produce matrices of overlap data with which heat maps can be generated.
1 | vectorheat(mod1, mod2)
|
mod1 |
A list of model objects, each element of which will be the first data set to compare in the 'singleheatmat' function. This function is intended to recieve the first element of the list produced by 'getcombos'. |
mod2 |
The second list of model objects, each element of which will be the second data set to compare in the 'singleheatmat' function. This function is intended to recieve the second element of the list produced by 'getcombos'. |
Returns a list, each element of which is matrix of the sampling distribution overlaps as produced by 'singleheatmat'.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.